@@ -19,6 +19,8 @@
  */
 
 #include "search.h"
+#include "options.h"
+#include "tags.h"
 #include "util.h"
 #include "charset.h"
 
@@ -148,6 +150,21 @@ add_constraints(int argc, char ** argv, struct mpd_connection *conn)
 static int
 do_search(int argc, char ** argv, struct mpd_connection *conn, bool exact)
 {
+	bool command_list = false;
+
+#if LIBMPDCLIENT_CHECK_VERSION(2,12,0)
+	/* ask MPD to omit the tags which are not used by the
+	   `--format` to reduce network transfer for tag values we're
+	   not going to use anyway (requires MPD 0.21 and libmpdclient
+	   2.12) */
+	if (mpd_connection_cmp_server_version(conn, 0, 21, 0) >= 0) {
+		if (!mpd_command_list_begin(conn, false) ||
+		    !send_tag_types_for_format(conn, options.custom_format ? options.format : NULL))
+			printErrorAndExit(conn);
+		command_list = true;
+	}
+#endif
+
 	mpd_search_db_songs(conn, exact);
 	if (!add_constraints(argc, argv, conn))
 		return -1;
@@ -155,6 +172,9 @@ do_search(int argc, char ** argv, struct mpd_connection *conn, bool exact)
 	if (!mpd_search_commit(conn))
 		printErrorAndExit(conn);
 
+	if (command_list && !mpd_command_list_end(conn))
+		printErrorAndExit(conn);
+
 	print_entity_list(conn, MPD_ENTITY_TYPE_SONG);
 
 	my_finishCommand(conn);
